@@ -1,7 +1,7 @@
 /* -------------------------------------------------------------
 
 This file is a component of SDPA
-Copyright (C) 2004-2011 SDPA Project
+Copyright (C) 2004-2012 SDPA Project
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ example1.dat:
 
 "Example 1: mDim = 3, nBLOCK = 1, {2}"
    3  =  mDIM
-   1  =  nBOLCK
+   1  =  nBLOCK
    2  = bLOCKsTRUCT
 {48, -8, 20}
 { {-11,  0}, { 0, 23} }
