@@ -1,7 +1,7 @@
 /* -------------------------------------------------------------
 
 This file is a component of SDPA
-Copyright (C) 2004-2011 SDPA Project
+Copyright (C) 2004-2012 SDPA Project
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -19,8 +19,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 
 ------------------------------------------------------------- */
 
-#define DIMACS_PRINT 0
-
 #include "sdpa_io.h"
 #include "sdpa_linear.h"
 #include "sdpa_jordan.h"
@@ -279,8 +277,12 @@ void IO::setBlockStruct(FILE* fpData, InputData& inputData, int m,
 
   if (isDataSparse) {
     int i,j,k,l;
+    i=j=k=l = -1000; // dummy initialize
     double value;
+    value = -1000;
+    int lineNumber = 0;
     while (true) {
+      lineNumber++;
       if (fscanf(fpData,"%*[^0-9+-]%d",&k)<=0) {
 	break;
       }
@@ -306,13 +308,22 @@ void IO::setBlockStruct(FILE* fpData, InputData& inputData, int m,
         SOCP_index[k].push_back(l2);
       } else if (bs.blockType[l-1] == BlockStruct::btLP) {
         if (i!=j){
-          printf("invalid data file k:%d, l:%d, i:%d, j:%d, value:%lf\n",
+          printf("******** invalid data line %d, %d, %d, %d, %e ***\n",
                  k,l,i,j,value);
+	  printf("Line number [%d] in 5-element-lines is invalid\n", lineNumber);
+	  printf("Check your input file\n");
+	  printf("Note: -1000 may appear in the above invalid report line if the corresponding place is not read correctly.\n");
+
           rError("IO::initializeLinearSpace");
         }
         int l2 = bs.blockNumber[l-1];
         LP_index[k].push_back(l2+i-1);
       } else {
+          printf("******** invalid data line %d, %d, %d, %d, %e ***\n",
+                 k,l,i,j,value);
+	  printf("Line number [%d] in 5-element-lines is invalid\n", lineNumber);
+	  printf("Check your input file\n");
+	  printf("Note: -1000 may appear in the above invalid report line if the corresponding place is not read correctly.\n");
         rError("io::read not valid blockType");
       }
     }// end of 'while (true)'
@@ -346,6 +357,7 @@ void IO::setBlockStruct(FILE* fpData, InputData& inputData, int m,
           }
         }
       } else {
+	rMessage("Current block number is " << l << ", but");
         rError("io::read not valid blockType");
       }
     }
@@ -377,6 +389,7 @@ void IO::setBlockStruct(FILE* fpData, InputData& inputData, int m,
             }
           }
         } else {
+	  rMessage("Current block number is " << l << ", but");
           rError("io::read not valid blockType");
         }
       }
@@ -757,14 +770,6 @@ void IO::printLastInfo(int pIteration,
     com.display(fpout);
   }
 
-  #if DIMACS_PRINT
-  double dimacs_error[DIMACS_ERROR_NUMBER+1];
-  computeDimacs(dimacs_error,solveInfo, currentRes, currentPt,
-		inputData, work);
-  printDimacs(dimacs_error, param, fpout);
-  printDimacs(dimacs_error, param, Display);
-  #endif
-
 }
 
 void IO::computeDimacs(double* dimacs_error,
