@@ -1,7 +1,7 @@
 /* -------------------------------------------------------------
 
 This file is a component of SDPA
-Copyright (C) 2004-2011 SDPA Project
+Copyright (C) 2004-2012 SDPA Project
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -272,7 +272,7 @@ void Parameter::display(FILE* fpout, char* printFormat)
     fprintf(fpout,"%s\n",NO_P_FORMAT);
     return;
   }
-  fprintf(fpout, "** Paramters **\n");
+  fprintf(fpout, "** Parameters **\n");
   fprintf(fpout, "maxIteration = %d\n",maxIteration);
   fprintf(fpout, "epsilonStar  = ");
   fprintf(fpout, printFormat, epsilonStar );
